/* Popular Assembler Standard Types
 * 
 * Those are highly used on Amiga and on several other machines,
 * especially good for very low-level programming, direct hardware IO, etc,
 * also well suited to fit with assembly stubs and such.
 * 
 * NOTES: For instance, int may be 16-bit on some machines/compilers, and
 * 32-bits on others... We thus cannot rely on the size of int. However we
 * can rely on the size of WORD and LONG. However, I keep using int for very
 * standard procedures (eg: int main(int argc...) ) as those serve as gateways
 * to the current OS it is running on, we cannot temper with them. Also, for
 * the same reason, low-io filehandles (filedescriptors) must also always be
 * referenced as int. But for everything we control entirely, we should use
 * those standard more obvious types which make C much more consistent.
 * 
 * (Matthew Mondor)
 */

#ifndef MMTYPES_H

#define MMTYPES_H

typedef signed char BYTE;
typedef unsigned char UBYTE;
typedef signed short WORD;
typedef unsigned short UWORD;
typedef signed long LONG;
typedef unsigned long ULONG;
typedef signed long long DLONG;
typedef unsigned long long UDLONG;
typedef float FLOAT;
typedef double DOUBLE;
typedef char BOOL;
typedef void VOID;

#ifndef NULL
#define NULL            (0L)
#endif

#ifndef TRUE
#define TRUE            (1)
#endif

#ifndef FALSE
#define FALSE           (0)
#endif

#endif

/*
	vim:ts=3:sw=3:cindent:
*/
